@@ -1,8 +1,5 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_cpu_cpu
-#define FF_INCLUDED_detection_cpu_cpu
-
 #include "fastfetch.h"
 
 #define FF_CPU_TEMP_UNSET (0/0.0)
@@ -16,12 +13,10 @@ typedef struct FFCPUResult
     uint16_t coresLogical;
     uint16_t coresOnline;
 
-    double frequencyMin;
-    double frequencyMax;
+    double frequencyMin; // GHz
+    double frequencyMax; // GHz
 
     double temperature;
 } FFCPUResult;
 
-const FFCPUResult* ffDetectCPU(const FFinstance* instance);
-
-#endif
+const char* ffDetectCPU(const FFCPUOptions* options, FFCPUResult* cpu);
